=== modified file 'NEWS'
--- NEWS	2008-03-15 22:34:18 +0000
+++ NEWS	2008-03-16 01:03:08 +0000
@@ -31,6 +31,9 @@
 
     * Restore auto-detection of plink.exe on Windows. (Dmitry Vasiliev)
 
+    * Version number is now shown as "1.2" or "1.2pr2", without zeroed or
+      missing final fields.  (Martin Pool)
+
     * The backup directory created by ``upgrade`` is now called
       ``backup.bzr``, not ``.bzr.backup``. (Martin Albisetti)
 

=== modified file 'README'
--- README	2008-01-04 00:42:06 +0000
+++ README	2008-01-16 01:30:17 +0000
@@ -26,44 +26,44 @@
 Bazaar highlights
 =================
 
- * Easy to use and intuitive.
-
-   Only five commands are needed to do all basic operations, and all
-   commands have documentation accessible via 'bzr help command'.
-   Bazaar's interface is also easy to learn for CVS and Subversion users.
-
- * Robust and reliable.
-
-   Bazaar is developed under an extensive test suite. Branches can be
-   checked and verified for integrity at any time, and revisions can be
-   signed with PGP/GnuPG.
-
- * Publish branches with HTTP.
-
-   Branches can be hosted on an HTTP server with no need for special
-   software on the server side. Branches can be uploaded by bzr itself
-   over SSH (SFTP), or with rsync.
-
- * Adapts to multiple environments.
-
-   Bazaar runs on Linux and Windows, fully supports Unicode filenames,
-   and suits different development models, including centralized.
-
- * Easily extended and customized.
-
-   A rich Python interface is provided for extending and embedding,
-   including a plugin interface. There are already many available plugins,
-   most of them registered at http://bazaar-vcs.org/PluginRegistry.
-
- * Smart merging.
-
-   Changes will never be merged more than once, conflicts will be
-   minimized, and identical changes are dealt with well.
-
- * Vibrant and active community.
-
-   Help with Bazaar is obtained easily, via the mailing list, or the IRC
-   channel.
+* Easy to use and intuitive.
+
+  Only five commands are needed to do all basic operations, and all
+  commands have documentation accessible via 'bzr help command'.
+  Bazaar's interface is also easy to learn for CVS and Subversion users.
+
+* Robust and reliable.
+
+  Bazaar is developed under an extensive test suite. Branches can be
+  checked and verified for integrity at any time, and revisions can be
+  signed with PGP/GnuPG.
+
+* Publish branches with HTTP.
+
+  Branches can be hosted on an HTTP server with no need for special
+  software on the server side. Branches can be uploaded by bzr itself
+  over SSH (SFTP), or with rsync.
+
+* Adapts to multiple environments.
+
+  Bazaar runs on Linux and Windows, fully supports Unicode filenames,
+  and suits different development models, including centralized.
+
+* Easily extended and customized.
+
+  A rich Python interface is provided for extending and embedding,
+  including a plugin interface. There are already many available plugins,
+  most of them registered at http://bazaar-vcs.org/PluginRegistry.
+
+* Smart merging.
+
+  Changes will never be merged more than once, conflicts will be
+  minimized, and identical changes are dealt with well.
+
+* Vibrant and active community.
+
+  Help with Bazaar is obtained easily, via the mailing list, or the IRC
+  channel.
 
 
 Registration and Feedback
@@ -72,19 +72,19 @@
 If you encounter any problems with Bazaar, need help understanding it, or would
 like to offer suggestions or feedback, please get in touch with us:
 
- * Ask a question through our web support interface, at 
-   https://answers.launchpad.net/bzr/
-
- * Report bugs at https://bugs.edge.launchpad.net/bzr/+filebug
-
- * Write to us at bazaar@lists.canonical.com 
-   You can join the list at <https://lists.ubuntu.com/mailman/listinfo/bazaar>.
-   You don't need to subscribe to post, but your first post will be held 
-   briefly for manual moderation.
-
- * Talk to us in irc://irc.ubuntu.com/bzr
-
- * And see http://bazaar-vcs.org/BzrSupport for more.
+* Ask a question through our web support interface, at 
+  https://answers.launchpad.net/bzr/
+
+* Report bugs at https://bugs.edge.launchpad.net/bzr/+filebug
+
+* Write to us at bazaar@lists.canonical.com 
+  You can join the list at <https://lists.ubuntu.com/mailman/listinfo/bazaar>.
+  You don't need to subscribe to post, but your first post will be held 
+  briefly for manual moderation.
+
+* Talk to us in irc://irc.ubuntu.com/bzr
+
+* And see http://bazaar-vcs.org/BzrSupport for more.
 
 If you would like to help us improve Bazaar by telling us about yourself and
 what we could do better, please register and complete the online survey here:

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2008-02-25 07:28:29 +0000
+++ bzrlib/__init__.py	2008-03-16 08:25:21 +0000
@@ -46,11 +46,48 @@
 # API compatibility version: bzrlib is currently API compatible with 0.18.
 api_minimum_version = (0, 18, 0)
 
-if version_info[3] == 'final':
-    version_string = '%d.%d.%d' % version_info[:3]
-else:
+def _format_version_tuple(version_info):
+    """Turn a version number 5-tuple into a short string.
+
+    This format matches <http://docs.python.org/dist/meta-data.html>
+    and the typical presentation used in Python output.
+
+    This also checks that the version is reasonable: the sub-release must be
+    zero for final releases, and non-zero for alpha, beta and preview.
+
+    >>> print _format_version_tuple((1, 0, 0, 'final', 0))
+    1.0
+    >>> print _format_version_tuple((1, 2, 0, 'dev', 0))
+    1.2dev
+    >>> print _format_version_tuple((1, 1, 1, 'candidate', 2))
+    1.1.1rc2
+    """
+    if version_info[2] == 0:
+        main_version = '%d.%d' % version_info[:2]
+    else:
+        main_version = '%d.%d.%d' % version_info[:3]
+
+    __release_type = version_info[3]
+    __sub = version_info[4]
+
+    # check they're consistent
+    if __release_type == 'final' and __sub == 0:
+        __sub_string = ''
+    elif __release_type == 'dev' and __sub == 0:
+        __sub_string = 'dev'
+    elif __release_type in ('alpha', 'beta') and __sub != 0:
+        __sub_string = __release_type[0] + str(__sub)
+    elif __release_type == 'candidate' and __sub != 0:
+        __sub_string = 'rc' + str(__sub)
+    else:
+        raise AssertionError("version_info %r not valid" % version_info)
+
     version_string = '%d.%d.%d.%s.%d' % version_info
-__version__ = version_string
+    return main_version + __sub_string
+
+__version__ = _format_version_tuple(version_info)
+version_string = __version__
+
 
 # allow bzrlib plugins to be imported.
 import bzrlib.plugin

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2008-03-06 14:12:45 +0000
+++ bzrlib/tests/__init__.py	2008-03-16 00:28:48 +0000
@@ -111,6 +111,7 @@
 
 MODULES_TO_TEST = []
 MODULES_TO_DOCTEST = [
+        bzrlib,
         bzrlib.timestamp,
         bzrlib.errors,
         bzrlib.export,

=== modified file 'setup.py'
--- setup.py	2008-03-11 08:49:42 +0000
+++ setup.py	2008-03-16 00:28:48 +0000
@@ -7,25 +7,55 @@
 """
 
 import os
+import os.path
 import sys
 
 if sys.version_info < (2, 4):
     sys.stderr.write("[ERROR] Not a supported Python version. Need 2.4+\n")
     sys.exit(1)
 
+# NOTE: The directory containing setup.py, whether run by 'python setup.py' or
+# './setup.py' or the equivalent with another path, should always be at the
+# start of the path, so this should find the right one...
 import bzrlib
 
+def get_long_description():
+    dirname = os.path.dirname(__file__)
+    readme = os.path.join(dirname, 'README')
+    f = open(readme, 'rb')
+    try:
+        return f.read()
+    finally:
+        f.close()
+
+
 ##
 # META INFORMATION FOR SETUP
-
-META_INFO = {'name':         'bzr',
-             'version':      bzrlib.__version__,
-             'author':       'Canonical Ltd',
-             'author_email': 'bazaar@lists.canonical.com',
-             'url':          'http://www.bazaar-vcs.org/',
-             'description':  'Friendly distributed version control system',
-             'license':      'GNU GPL v2',
-            }
+# see http://docs.python.org/dist/meta-data.html
+META_INFO = {
+    'name':         'bzr',
+    'version':      bzrlib.__version__,
+    'author':       'Canonical Ltd',
+    'author_email': 'bazaar@lists.canonical.com',
+    'url':          'http://www.bazaar-vcs.org/',
+    'description':  'Friendly distributed version control system',
+    'license':      'GNU GPL v2',
+    'download_url': 'http://bazaar-vcs.org/Download',
+    'long_description': get_long_description(),
+    'classifiers': [
+        'Development Status :: 6 - Mature',
+        'Environment :: Console',
+        'Intended Audience :: Developers',
+        'Intended Audience :: System Administrators',
+        'License :: OSI Approved :: GNU General Public License (GPL)',
+        'Operating System :: Microsoft :: Windows',
+        'Operating System :: OS Independent',
+        'Operating System :: POSIX',
+        'Programming Language :: Python',
+        'Programming Language :: C',
+        'Topic :: Software Development :: Version Control',
+        ],
+    }
 
 # The list of packages is automatically generated later. Add other things
 # that are part of BZRLIB here.

